==> igniteui-angular-charts-14.1.1.tgz: package/esm5/lib/Stacked100DataPreparer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var Stacked100DataPreparer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100DataPreparer, _super);
    function Stacked100DataPreparer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100DataPreparer.a = function (a) {
        if (a.ck == null) {
            return;
        }
        var b = Number.POSITIVE_INFINITY;
        var c = Number.NEGATIVE_INFINITY;
        for (var d = 0; d < a.ck.count; d++) {
            var e = Math.abs(a.tf[d]) + a.te[d];
            if (e == 0) {
                b = Math.min(b, 0);
                c = Math.max(c, 0);
                continue;
            }
            b = Math.min(b, a.tf[d] / e * 100);
            c = Math.max(c, a.te[d] / e * 100);
        }
        a.tw = b;
        a.tv = c;
    };
    Stacked100DataPreparer.$t = markType(Stacked100DataPreparer, 'Stacked100DataPreparer');
    return Stacked100DataPreparer;
}(Base));
export { Stacked100DataPreparer };

==> igniteui-angular-charts-16.0.0.tgz: package/esm5/lib/Stacked100DataPreparer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var Stacked100DataPreparer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100DataPreparer, _super);
    function Stacked100DataPreparer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100DataPreparer.a = function (a) {
        if (a.ck == null) {
            return;
        }
        var b = Number.POSITIVE_INFINITY;
        var c = Number.NEGATIVE_INFINITY;
        for (var d = 0; d < a.ck.count; d++) {
            var e = Math.abs(a.tj[d]) + a.ti[d];
            if (e == 0) {
                b = Math.min(b, 0);
                c = Math.max(c, 0);
                continue;
            }
            b = Math.min(b, a.tj[d] / e * 100);
            c = Math.max(c, a.ti[d] / e * 100);
        }
        a.t0 = b;
        a.tz = c;
    };
    Stacked100DataPreparer.$t = markType(Stacked100DataPreparer, 'Stacked100DataPreparer');
    return Stacked100DataPreparer;
}(Base));
export { Stacked100DataPreparer };
